<?php
/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.0.0
 * @package    litesmash
 * @subpackage litesmash/includes
 * @author     litesmash <contact@litesmash.com>
 */
class LiteSmash_Activator {

	public static function activate($network_wide) {
		global $wpdb;
		if ( is_multisite() && $network_wide ) {
			// Get all blogs in the network and activate plugin on each one
			$blog_ids = $wpdb->get_col( "SELECT blog_id FROM $wpdb->blogs" );
			foreach ( $blog_ids as $blog_id ) {
				switch_to_blog( $blog_id );
				self::ls_plugin_activate();
				restore_current_blog();
			}
		} else {
			self::ls_plugin_activate();
		}
	}
	
	public function ls_plugin_activate(){
		//self::zpr_events_table();
		self::ls_list_builder();
		self::ls_traffic_lists();
		self::ls_traffic_leads();
		self::ls_traffic_campaign_settings();
	}	
	
	public function ls_list_builder() {
		global $wpdb;
		$table_name = $wpdb->prefix . 'list_builder';
		if( $wpdb->get_var( "show tables like '{$table_name}'" ) != $table_name ) {
			$sql = "CREATE TABLE " . $table_name . " (
			  id mediumint(20) NOT NULL AUTO_INCREMENT,
			  name varchar(255) NOT NULL,
			  email varchar(255) NOT NULL,
			  updated_at timestamp NULL DEFAULT NULL,
			  created_at timestamp NULL DEFAULT NULL,
			  PRIMARY KEY  (id)
			);";
			require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
			dbDelta( $sql );
		}
	}
	public function ls_traffic_lists() {
		global $wpdb;
		$table_name = $wpdb->prefix . 'ls_traffic_lists';
		if( $wpdb->get_var( "show tables like '{$table_name}'" ) != $table_name ) {
			$sql = "CREATE TABLE " . $table_name . " (
			  id mediumint(20) NOT NULL AUTO_INCREMENT,
			  name varchar(255) NOT NULL,
			  description longtext NOT NULL,
			  updated_at timestamp NULL DEFAULT NULL,
			  created_at timestamp NULL DEFAULT NULL,
			  PRIMARY KEY  (id)
			);";
			require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
			dbDelta( $sql );
		}
	}
	public function ls_traffic_leads() {
		global $wpdb;
		$table_name = $wpdb->prefix . 'ls_traffic_leads';
		if( $wpdb->get_var( "show tables like '{$table_name}'" ) != $table_name ) {
			$sql = "CREATE TABLE " . $table_name . " (
			  id mediumint(20) NOT NULL AUTO_INCREMENT,
			  listid varchar(255) NOT NULL,
			  email varchar(500) NOT NULL,
			  updated_at timestamp NULL DEFAULT NULL,
			  created_at timestamp NULL DEFAULT NULL,
			  PRIMARY KEY  (id)
			);";
			require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
			dbDelta( $sql );
		}
	}
	public function ls_traffic_campaign_settings() {
		global $wpdb;
	    global $user_ID;
		
		/* subscribe template */
		$unsub_post = array(
			'post_title'   => 'ListSmasher Unsubscribe',
			'post_content' => 'You are succsessfully unsubscribed',
			'post_name'    => 'listsmasher-unsubscribe',
			'post_status'  => 'publish',
			'post_date'    => date('Y-m-d H:i:s'),
			'post_author'  => $user_ID,
			'post_type'    => 'page',
			'post_category'=> array(0)
		);
		
		$hw_unsub = self::wpls_slug_exists('listsmasher-unsubscribe');
		if($hw_unsub){
			$post_id2 = $hw_unsub;
		}else{ 
		    $post_id2 = wp_insert_post($unsub_post);
		}	
		
		if(!$post_id2){
			//wp_die('Error creating template page');
		} else {
			$post2 = get_post($post_id2); 
            $slug2 = $post2->post_name;
			update_option('listsmasher_unsubscribe',$post_id2);
			update_option('listsmasher_unsubscribe_slug',$slug2);
			update_post_meta($post_id2, '_wp_page_template', 'tpls-unsubscribe.php');
		}		
	}	
	public function wpls_slug_exists($post_name) {
		global $wpdb;
		$post_name = sanitize_title($post_name);
		$row=$wpdb->get_row("SELECT ID,post_name FROM ".$wpdb->prefix."posts WHERE post_name = '" . $post_name . "'");
		if($row) {
			return $row->ID;
		} else {
			return false;
		}
	}	
	
}
