<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://lostwebdesigns.com
 * @since      1.0.0
 *
 * @package    Wp_Cbf
 * @subpackage Wp_Cbf/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Wp_Cbf
 * @subpackage Wp_Cbf/admin
 * @author     Guillaume Kanoufi <g.kanoufi@gmail.com>
 */
class Wpls_email_traffic {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		
		add_action('wp_ajax_wpls_delete_list_leads',array($this, 'wpls_delete_list_leads_process'));
        add_action('wp_ajax_nopriv_wpls_delete_list_leads', array($this, 'wpls_delete_list_leads_process'));
		
		add_action('wp_ajax_wpls_delete_leads',array($this, 'wpls_delete_leads_process'));
        add_action('wp_ajax_nopriv_wpls_delete_leads', array($this, 'wpls_delete_leads_process'));
		
		add_action('wp_ajax_wpls_delete_optin_form',array($this, 'wpls_delete_optin_form_process'));
        add_action('wp_ajax_nopriv_wpls_delete_optin_form', array($this, 'wpls_delete_optin_form_process'));
		
		add_action('wp_ajax_wpls_save_optin_form_box',array($this, 'wpls_save_optin_form_box_process'));
        add_action('wp_ajax_nopriv_wpls_save_optin_form_box', array($this, 'wpls_save_optin_form_box_process'));

		add_action('wp_ajax_wpls_export_list_leads',array($this, 'wpls_export_list_leads_process'));
        add_action('wp_ajax_nopriv_wpls_export_list_leads', array($this, 'wpls_export_list_leads_process'));		
		
        if(get_option('ls_optin_form_box',false)=='yes'){
		add_filter('the_content', array($this, 'wpls_show_optin_form_box'));
		}
		
		add_shortcode( 'ls_form', array($this, 'wpls_optin_form_shortcode'));
        if(get_option('ts_traffic_rescue',false)=='yes'){
		add_action( 'template_redirect',array($this,'wpts_traffic_rescue_on_404')  );
        }		
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {
    	//wp_enqueue_style( $this->plugin_name.'_traffic_css', plugin_dir_url( __FILE__ ) . 'css/wpts-email-traffic.css', array(), $this->version, 'all' );
	}

	public function enqueue_scripts() {
		//wp_enqueue_script( $this->plugin_name.'_traffic_js', plugin_dir_url( __FILE__ ) . 'js/wpts-email-traffic.js', array( 'jquery' ), $this->version, false );
	}

	/**
	 * Register the administration menu for this plugin into the WordPress Dashboard menu.
	 *
	 * @since    1.0.0
	 */
	public function add_plugin_admin_menu() {
		add_submenu_page('listsmasher', 'Auto Responder', 'Auto Responder', 'manage_options', 'ls-email-traffic', array($this, 'wpls_email_traffic_page') );
		add_submenu_page('', '', '', 'manage_options', 'ls-email-setting', array($this, 'wpls_email_setting_page') );
	}

	/**
	 * Render the settings page for this plugin.
	 *
	 * @since    1.0.0
	 */
	public function wpls_email_traffic_page() {
		include_once( 'partials/wpts-email-traffic-display.php' );
	}
	public function wpts_traffic_rescue_page() {
		include_once( 'rescue/wpts-traffic-rescue-display.php' );
	}	
	public function wpls_email_setting_page() {
		include_once( 'partials/wpls-email-settings-display.php' );
	}	
	
	public function wpls_delete_list_leads_process() {
		global $wpdb;
		$listid = $_POST['listid'];
    	$ts_traffic_lists = $wpdb->prefix."ls_traffic_lists";
		$wpdb->query("DELETE  FROM ".$ts_traffic_lists." WHERE id=$listid");
    	$ts_traffic_leads = $wpdb->prefix."ls_traffic_leads";
		$wpdb->query("DELETE  FROM ".$ts_traffic_leads." WHERE listid=$listid");
		die();		
	}
	
	public function wpls_delete_leads_process() {
		global $wpdb;
		$leadid = $_POST['leadid'];
    	$ts_traffic_leads = $wpdb->prefix."ls_traffic_leads";
		$wpdb->query("DELETE  FROM ".$ts_traffic_leads." WHERE id=$leadid");
		die();		
	}	
	public function wpls_delete_optin_form_process() {
		global $wpdb;
		$formid = $_POST['formid'];
    	$ts_traffic_optin_forms = $wpdb->prefix."ls_traffic_optin_forms";
		$wpdb->query("DELETE  FROM ".$ts_traffic_optin_forms." WHERE id=$formid");
		die();		
	}
    public function wpls_save_optin_form_box_process() {
		global $wpdb;
		$listid = $_POST['listid'];
		$email  = $_POST['email'];
		
		$ts_traffic_leads = $wpdb->prefix . 'ls_traffic_leads';
		$message='';
		if(isset($email) && $email!='' && isset($listid) && $listid!=''){
			if (filter_var($email, FILTER_VALIDATE_EMAIL)) {

				$insert = array(
							'email'   => $email,			
							'listid'  => $listid,
							'updated_at'=> date('Y-m-d-H:i:s'),				
							'created_at'=> date('Y-m-d-H:i:s'),	
						  );
				try{
					$resp =  $wpdb->insert($ts_traffic_leads,$insert);
					if($wpdb->insert_id) {
						$post_id= $wpdb->insert_id;
						//ts_save_video_to_server($post_id);
						//echo 'success';
						$message = '<div class="alert alert-success"><p>List saved successfully</p></div>';
					}else{
						//print_r($wpdb->last_error);
						$message ='<div class="alert alert-danger"><p>'.$wpdb->print_error().'</p></div>';
						//echo $wpdb->print_error();
					}
				}catch(\Exception $e){
					//print_r($e->getMessage());
					$message ='<div class="alert alert-danger"><p>'.$e->getMessage().'</p></div>';
					//die('ERROR');
				}	
			}	

			echo $message;
		}		
    }		
	
	
	public function wpls_show_optin_form_box($content) {
		
		$ts_optin_form_box_id = get_option('ls_optin_form_box_id',false);
		if(!empty($ts_optin_form_box_id)){
			global $wpdb;
			$ts_traffic_optin_forms = $wpdb->prefix."ls_traffic_optin_forms";
			$forms = $wpdb->get_row("SELECT * from  " . $ts_traffic_optin_forms."  WHERE id=".$ts_optin_form_box_id." ORDER BY id DESC");			
			if(!empty($forms)){
			$my_custom_text='';
			//echo"<pre>";print_r($forms);echo"</pre>";
			$data  = unserialize($forms->content);
			$listid = $data['listid'];
			$formid = $data['name'];
			//echo"<pre>";print_r($data);echo"</pre>"; 
			$form_1 ='  <div class="ts-get-free-outer">
						  <div class="ts-get-free" style="font-size:'.$data['title_size'].'px;font-family:'.$data['title_font'].';color:'.$data['title_color'].';">'.$data['title'].'</div>
						  <div class="ts-signup-div" style="font-size:'.$data['subtitle_size'].'px;font-family:'.$data['subtitle_font'].';color:'.$data['subtitle_color'].';">'.$data['subtitle'].'</div>
						  <div style="display:inline-block;">
							<div class="ts-form-inner">
							  <div class="ts-form-icon">
								<img src="'.LS_PLUGIN_URL.'public/img/user.png" alt="img">
								<input type="text" name="ts_name" id="ts_name" class="input-inner" value="" placeholder="'.$data['ph_name'].'" />
							  </div>
							  <div class="ts-form-icon">
								<img src="'.LS_PLUGIN_URL.'public/img/email.png" alt="img">
								<input
								  type="text" 
								  name="ts_email" id="ts_email"
								  class="input-inner"
								  value=""
								  placeholder="'.$data['ph_email'].'"
								/>
							  </div>
							  <div class="ts-form-icon">
							  <input type="hidden" name="ts_listid" id="ts_listid" value="'.$forms->listid.'" />
							  <button class="ts_save_optin_form button-inner" style="font-size:'.$data['button_text_size'].'px;font-family:'.$data['button_text_font'].';color:'.$data['button_text_color'].';background-color:'.$data['button_text_bgcolor'].';">'.$data['button_text'].'</button>
							</div>
							</div>
							<div class="ts-footer-text" style="font-size:'.$data['content_size'].'px;font-family:'.$data['content_font'].';color:'.$data['content_color'].';">'.$data['content'].'</div>
						  </div>
						</div>';

            $form_2 ='  <div class="ts-outter ts-col-12 pad-none">
						  <div class="ts-inner-form pad-none">
							  <div class="join-our-inner" style="font-size:'.$data['title_size'].'px;font-family:'.$data['title_font'].';color:'.$data['title_color'].';">'.$data['title'].'</div>
							  <div class="ts-join-div">
								<img src="'.LS_PLUGIN_URL.'public/img/user.png" alt="img">
								<input type="text" name="ts_name" id="ts_name" class="join-form" value="" placeholder="'.$data['ph_name'].'" />
							  </div>
							  <div class="ts-join-div">
								<img src="'.LS_PLUGIN_URL.'public/img/email.png" alt="img">
								<input type="text" name="ts_email" id="ts_email" class="join-form" value="" placeholder="'.$data['ph_email'].'" />
							  </div>
							  <div class="subscribe-outter">
    							<input type="hidden" name="ts_listid" id="ts_listid" value="'.$forms->listid.'" />
								<button class="ts_save_optin_form subscribe" style="font-size:'.$data['button_text_size'].'px;font-family:'.$data['button_text_font'].';color:'.$data['button_text_color'].';background-color:'.$data['button_text_bgcolor'].';">'.$data['button_text'].'</button>
							</div>
						  </div>
						  <div class="ts-left-div pad-none">
							<div class="ts-left-div-inner" style="font-size:'.$data['subtitle_size'].'px;font-family:'.$data['subtitle_font'].';color:'.$data['subtitle_color'].';">'.$data['subtitle'].'</div>
							<div class="ts-left-span-inner" style="font-size:'.$data['content_size'].'px;font-family:'.$data['content_font'].';color:'.$data['content_color'].';">'.$data['content'].'</div>
						  </div>
						</div>';

            $form_3 =   '<div class="ts-receive-outer">
						  <div class="ts-form-inner">
    						  <div class="ts-receive-inner" style="font-size:'.$data['title_size'].'px;font-family:'.$data['title_font'].';color:'.$data['title_color'].';">'.$data['title'].'</div>
							  <div class="ts-icon-div">
								<img src="'.LS_PLUGIN_URL.'public/img/email.png" alt="img">
								<input type="text" name="ts_email" id="ts_email" class="receive-div" value="" placeholder="'.$data['ph_email'].'" required />
							    <input type="hidden" name="ts_listid" id="ts_listid" value="'.$forms->listid.'" />
								<button class="ts_save_optin_form sign-div" style="font-size:'.$data['button_text_size'].'px;font-family:'.$data['button_text_font'].';color:'.$data['button_text_color'].';background-color:'.$data['button_text_bgcolor'].';">'.$data['button_text'].'</button>
							  </div>
						  </div>
						</div>';			  

           $sform = 'form_'.$formid;
			//$my_custom_text .= $form_1;
			//$my_custom_text .= '<br>';
			//$my_custom_text .= $form_2;
			//$my_custom_text .= '<br>';
            $my_custom_text .= $$sform; 
			$my_custom_text .='<script>
			jQuery(document).ready(function($){
				$(document).on("click", ".ts_save_optin_form", function() {
					$("#ts_email").css("border","1px solid #6e7071");
					var email  = $("#ts_email").val();
					if (email == "") {
						$("#ts_email").css("border","1px solid red");
						return false;
					}
					var listid = $("#ts_listid").val();
						
					var url = wpts_ajax.ajax_url;
					jQuery.ajax({
						url:  url,
						type: "POST",
						data: {
							action:"wpls_save_optin_form_box",
							email:email,
							listid:listid,
						},
						beforeSend: function(){
							$(".ts_save_optin_form").html("Saving...");
						},
						success: function (response) {
							$(".ts_save_optin_form").html("Done!");
							return false;
						}
					});	
		
				});
			});	
			

			</script>';			  
			//$my_custom_text .= 'Place the text you wish to insert below your post content here. Do not delete the single quote marks.'; 

			if(is_single() && !is_home()) {
			$content .= $my_custom_text;
			}
		    return $content;
		}else{
			return $content;
		}	
		}else{
		    return $content;	
        } 		
		
	}
	
	
	public function wpls_optin_form_shortcode($atts ) {
	    $atts = shortcode_atts( array(
			'id' => '1',
			'listid' => '1'
		), $atts, 'ts_form' );
		$content='';
		$ts_optin_form_box_id = $atts['id'];
		if(!empty($ts_optin_form_box_id)){
			global $wpdb;
			$ts_traffic_optin_forms = $wpdb->prefix."ls_traffic_optin_forms";
			$forms = $wpdb->get_row("SELECT * from  " . $ts_traffic_optin_forms."  WHERE id=".$ts_optin_form_box_id." ORDER BY id DESC");			
			if(!empty($forms)){
			$my_custom_text='';
			//echo"<pre>";print_r($forms);echo"</pre>";
			$data  = unserialize($forms->content);
			$listid = $data['listid'];
			$formid = $data['name'];
			//echo"<pre>";print_r($data);echo"</pre>"; 
			/* $form_1 ='  <div class="ts-get-free-outer">
						  <div class="ts-get-free">get free email updates !</div>
						  <div class="ts-signup-div">
							signup now and receive an email once i publish new content.
						  </div>
						  <div style="display:inline-block;">
							<div class="ts-form-inner">
							  <div class="ts-form-icon">
								<img src="'.TS_PLUGIN_URL.'public/img/user.png" alt="img">
								<input type="text" name="tssc_name" id="tssc_name" class="input-inner" value="" placeholder="enter your name" />
							  </div>
							  <div class="ts-form-icon">
								<img src="'.TS_PLUGIN_URL.'public/img/email.png" alt="img">
								<input
								  type="text" 
								  name="tssc_email" id="tssc_email"
								  class="input-inner"
								  value=""
								  placeholder="enter your email address"
								/>
							  </div>
							  <div class="ts-form-icon">
							  <input type="hidden" name="tssc_listid" id="tssc_listid" value="'.$forms->listid.'" />
							  <button class="tssc_save_optin_form button-inner">sign up</button>
							</div>
							</div>
							<div class="ts-footer-text">
							  Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean
							  commodo ligula eget dolor.
							</div>
						  </div>
						</div>'; */
			$form_1 ='  <div class="ts-get-free-outer">
						  <div class="ts-get-free" style="font-size:'.$data['title_size'].'px;font-family:'.$data['title_font'].';color:'.$data['title_color'].';">'.$data['title'].'</div>
						  <div class="ts-signup-div" style="font-size:'.$data['subtitle_size'].'px;font-family:'.$data['subtitle_font'].';color:'.$data['subtitle_color'].';">'.$data['subtitle'].'</div>
						  <div style="display:inline-block;">
							<div class="ts-form-inner">
							  <div class="ts-form-icon">
								<img src="'.LS_PLUGIN_URL.'public/img/user.png" alt="img">
								<input type="text" name="ts_name" id="ts_name" class="input-inner" value="" placeholder="'.$data['ph_name'].'" />
							  </div>
							  <div class="ts-form-icon">
								<img src="'.LS_PLUGIN_URL.'public/img/email.png" alt="img">
								<input
								  type="text" 
								  name="ts_email" id="ts_email"
								  class="input-inner"
								  value=""
								  placeholder="'.$data['ph_email'].'"
								/>
							  </div>
							  <div class="ts-form-icon">
							  <input type="hidden" name="ts_listid" id="ts_listid" value="'.$forms->listid.'" />
							  <button class="ts_save_optin_form button-inner" style="font-size:'.$data['button_text_size'].'px;font-family:'.$data['button_text_font'].';color:'.$data['button_text_color'].';background-color:'.$data['button_text_bgcolor'].';">'.$data['button_text'].'</button>
							</div>
							</div>
							<div class="ts-footer-text" style="font-size:'.$data['content_size'].'px;font-family:'.$data['content_font'].';color:'.$data['content_color'].';">'.$data['content'].'</div>
						  </div>
						</div>';
            $form_2 ='  <div class="ts-outter ts-col-12 pad-none">
						  <div class="ts-inner-form pad-none">
							  <div class="join-our-inner" style="font-size:'.$data['title_size'].'px;font-family:'.$data['title_font'].';color:'.$data['title_color'].';">'.$data['title'].'</div>
							  <div class="ts-join-div">
								<img src="'.LS_PLUGIN_URL.'public/img/user.png" alt="img">
								<input type="text" name="ts_name" id="ts_name" class="join-form" value="" placeholder="'.$data['ph_name'].'" />
							  </div>
							  <div class="ts-join-div">
								<img src="'.LS_PLUGIN_URL.'public/img/email.png" alt="img">
								<input type="text" name="ts_email" id="ts_email" class="join-form" value="" placeholder="'.$data['ph_email'].'" />
							  </div>
							  <div class="subscribe-outter">
    							<input type="hidden" name="ts_listid" id="ts_listid" value="'.$forms->listid.'" />
								<button class="ts_save_optin_form subscribe" style="font-size:'.$data['button_text_size'].'px;font-family:'.$data['button_text_font'].';color:'.$data['button_text_color'].';background-color:'.$data['button_text_bgcolor'].';">'.$data['button_text'].'</button>
							</div>
						  </div>
						  <div class="ts-left-div pad-none">
							<div class="ts-left-div-inner" style="font-size:'.$data['subtitle_size'].'px;font-family:'.$data['subtitle_font'].';color:'.$data['subtitle_color'].';">'.$data['subtitle'].'</div>
							<div class="ts-left-span-inner" style="font-size:'.$data['content_size'].'px;font-family:'.$data['content_font'].';color:'.$data['content_color'].';">'.$data['content'].'</div>
						  </div>
						</div>';

            $form_3 =   '<div class="ts-receive-outer">
						  <div class="ts-form-inner">
    						  <div class="ts-receive-inner" style="font-size:'.$data['title_size'].'px;font-family:'.$data['title_font'].';color:'.$data['title_color'].';">'.$data['title'].'</div>
							  <div class="ts-icon-div">
								<img src="'.LS_PLUGIN_URL.'public/img/email.png" alt="img">
								<input type="text" name="ts_email" id="ts_email" class="receive-div" value="" placeholder="'.$data['ph_email'].'" required />
							    <input type="hidden" name="ts_listid" id="ts_listid" value="'.$forms->listid.'" />
								<button class="ts_save_optin_form sign-div" style="font-size:'.$data['button_text_size'].'px;font-family:'.$data['button_text_font'].';color:'.$data['button_text_color'].';background-color:'.$data['button_text_bgcolor'].';">'.$data['button_text'].'</button>
							  </div>
						  </div>
						</div>';				  
            $hg = 'form_'.$formid;
			//$my_custom_text .= $form_1;
			//$my_custom_text .= '<br>';
			//$my_custom_text .= $form_2;
			//$my_custom_text .= '<br>';
            $my_custom_text .= $$hg;  
			$my_custom_text .='<script>
			jQuery(document).ready(function($){
				$(document).on("click", ".tssc_save_optin_form", function() {
                    $("#tssc_email").css("border","1px solid #6e7071");
					var email  = $("#tssc_email").val();
					if (email == "") {
						$("#tssc_email").css("border","1px solid red");
						return false;
					}
					var listid = $("#tssc_listid").val();
						
					var url = wpts_ajax.ajax_url;
					jQuery.ajax({
						url:  url,
						type: "POST",
						data: {
							action:"wpts_save_optin_form_box",
							email:email,
							listid:listid,
						},
						beforeSend: function(){
							$(".tssc_save_optin_form").html("Saving...");
						},
						success: function (response) {
							$(".tssc_save_optin_form").html("Done!");
							return false;
						}
					});	
		
				});
			});	
			
			</script>';			  
			//$my_custom_text .= 'Place the text you wish to insert below your post content here. Do not delete the single quote marks.'; 

			if(is_single() && !is_home()) {
			$content .= $my_custom_text;
			}
		    return $content;
		}else{
			return $content;
		}	
		}else{
		    return $content;	
        } 	 
		
	}	

	public function wpls_traffic_rescue_on_404() {	
		if( is_404() ){
			$links = get_option('ls_traffic_rescue_links',false);
			$link = unserialize($links);
			$random = rand(1,count($link));
			$url = $link[$random]['url'];	
			
			wp_redirect($url);
			exit();
		}
	}	
	
	public function wpls_export_list_leads_process() {
		global $wpdb;
		$listid = $_POST['listid'];
    	//$ts_campaign_leads = $wpdb->prefix."ts_campaign_leads";
		
		$ls_traffic_leads = $wpdb->prefix . 'ls_traffic_leads';
		$leads = $wpdb->get_results("SELECT * FROM ".$ls_traffic_leads." WHERE listid = '".$listid."' ORDER BY id DESC");

		//$campaigns = $wpdb->get_results ("SELECT * from  " . $ts_campaign_leads." WHERE campaign_id =$campid");
		$list=array();
		
		if (!empty($leads)){
			$list[] =array('Email');	
			foreach($leads as $k=>$row){
				$list[] =array($row->email);
			}
		}

		$file = fopen(LS_PLUGIN_PATH."traffic/leads.csv","w");
		foreach ($list as $line) {
		    fputcsv($file, $line);
		}
		fclose($file);		
		die();		
		
	}
	
	
}
