<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://lostwebdesigns.com
 * @since      1.0.0
 *
 * @package    Wp_Cbf
 * @subpackage Wp_Cbf/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Wp_Cbf
 * @subpackage Wp_Cbf/admin
 * @author     Guillaume Kanoufi <g.kanoufi@gmail.com>
 */
class Wpls_vbuilder_traffic {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

		add_action('wp_ajax_wpls_save_optin_form',array($this, 'ajax_wpls_save_optin_form'));
        add_action('wp_ajax_nopriv_wpls_save_optin_form', array($this, 'ajax_wpls_save_optin_form'));
		
		add_action('wp_ajax_wpls_email_export_csv',array($this, 'wpls_email_export_csv_process'));
        add_action('wp_ajax_nopriv_wpls_email_export_csv', array($this, 'wpls_email_export_csv_process'));		
				
		add_filter('the_content', array($this, 'wpls_show_optin_form_boxx'));
		
		add_filter( 'page_template', array($this,'wpls_email_catch_plugin_template') );		
		add_action( 'init', array($this,'wpls_email_rewrites_init') );
		add_filter( 'query_vars', array($this,'wpls_email_query_vars') );		
		
		$highwayunsub = get_option('listsmasher_unsubscribe');
		$highwayunsubslug = get_option('listsmasher_unsubscribe_slug');		
		
	}

	public function wpls_email_catch_plugin_template( $template ) {
        $post = get_post();
        $page_template = get_post_meta( $post->ID, '_wp_page_template', true );
		if( 'tpls-unsubscribe.php' == basename( $page_template ) ){
			$template = WP_PLUGIN_DIR . '/ListSmasher/traffic/tpls-unsubscribe.php';
		}	
		return $template;
	}	
	public function wpls_email_rewrites_init(){
		$unsubslug = get_option('listsmasher_unsubscribe_slug',true);
		flush_rewrite_rules();
		add_rewrite_tag('%list_id%','([^/]+)');
		add_rewrite_tag('%lsemail%','([^/]+)');
		add_rewrite_rule(
			'^'.$unsubslug.'/([A-Za-z0-9\-\_]+)/([^/]+)',
			'index.php?pagename='.$unsubslug.'&list_id=$matches[1]&lsemail=$matches[2]',
			'top'
		);			
	}	
	
	public function wpls_email_query_vars( $query_vars ){
		$query_vars[] = 'list_id';
		$query_vars[] = 'lsemail';
		return $query_vars;
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() 
	{
    	wp_enqueue_style( $this->plugin_name.'-list_builder', plugin_dir_url( __FILE__ ) . 'css/wpls-viral-builder-traffic.css', array(), $this->version, 'all' );
	}

	public function enqueue_scripts() {
		//wp_enqueue_script( $this->plugin_name.'-pdf-gen', plugin_dir_url( __FILE__ ) . 'js/wpts-viral-builder-traffic.js', array( 'jquery' ), $this->version, false );
	}

	/**
	 * Register the administration menu for this plugin into the WordPress Dashboard menu.
	 *
	 * @since    1.0.0
	 */
	public function add_plugin_vbuilder_admin_menu() {
		//add_submenu_page('highway', 'Viral Campaign Builder', 'Viral Campaign Builder', 'manage_options', 'ts-viral-campaign', array($this, 'display_plugin_vbuilder_setup_page') );
		add_submenu_page('listsmasher', 'ListBuilder', 'List Builder ', 'manage_options', 'ls-list-builder', array($this, 'display_plugin_vbuilder_setup_page') );
		add_submenu_page('', '', '', 'manage_options', 'ls-option-form', array($this, 'display_plugin_ls_option_form') );
	}

	/**
	 * Render the settings page for this plugin.
	 *
	 * @since    1.0.0
	 */
	public function display_plugin_vbuilder_setup_page() {
		include_once( 'partials/wpls-viral-builder-traffic-display.php' );
	}
	
	public function display_plugin_ls_option_form() {
		include_once( 'partials/wpls-option-form-display.php' );
	}
	
	public function ajax_wpls_vbuilder_opt_result()
	{
		$template_val_vbuilder_layout = $_POST['ts_vbuilder_opt_val'];
		
		$option_name = 'ls_vbuilder_template_layout' ;
		$new_value = $template_val_vbuilder_layout;
		 
		if ( get_option( $option_name ) !== false ) 
		{
			update_option( $option_name, $new_value );		 
			?>
			<div class="wrap">
				<div class="updated"><p style="margin: 0px;padding: 5px;">Template is Updated.</p></div>
			</div>
			<?php
		} 
		else 
		{
			add_option( $option_name, $new_value);
			?>
			<div class="wrap">
				<div class="updated"><p style="margin: 0px;padding: 5px;">Template is saved.</p></div>
			</div>
			<?php
		}
		?>
		<script>
		jQuery(function() {
			setTimeout(function() {
				  jQuery('.updated').fadeOut('slow');
				}, 5000); // <-- time in milliseconds
		});
		</script>    
		<?php
		exit;
	}

	public function ajax_wpls_vbuilder_frontend_opt_result()
	{
		global $wpdb;
        
        ob_start();
        
        $subc_front_name = $_POST['ls_vbuilder_front_name_val'];
		$subc_email = $_POST['ls_vbuilder_front_email_val'];
		$subc_link = $_POST['ls_vbuilder_front_link_val'];
		$subc_content = stripslashes($_POST['ls_vbuilder_front_content_val']);
		$subc_id = $_POST['ls_vbuilder_front_id_val'];
		
		$old_words	= array("[ls_lockbuilders]", "[/ls_lockbuilders]");
		$new_words	= array("", "");

		$newphrase = str_replace($old_words, $new_words, $subc_content);
		
        $vbuilder_table = $wpdb->base_prefix . "list_builder";

        $vbuilder_count_check_result = $wpdb->get_results("SELECT * FROM ".$wpdb->base_prefix."list_builder WHERE name = '".$subc_front_name."' AND email = '".$subc_email."'");
        
        if (count($vbuilder_count_check_result) == 0)
        {
            $vbuilder_insert_data=array(
                                        'name' => $subc_front_name, 
                                        'email' => $subc_email, 
                                       );
    
            $vbuilder_insert = $wpdb->insert( $vbuilder_table, $vbuilder_insert_data); 
			if($vbuilder_insert)
			{
				?>
				<p style="color:#fff;">Content is unlocked.click here <a href="<?php echo $subc_link; ?>" style="text-decoration:none;color:#fff;"><i class="fa fa-share" aria-hidden="true"></i></a> to continue reading.</p>
				<?php			
				$cookie_name = "ls_subc_vbuilder_unlock_".$subc_id;
				$cookie_value = "ls_subc_vbuilder_unlock_value_".$subc_id;
				setcookie($cookie_name, $cookie_value, time() + (1 * 365 * 24 * 60 * 60), "/");			
			}
        }
		else
		{
			echo "11";
		}
		exit;
	}

	public function ajax_wpls_vbuilder_frontend_template2_opt_result()
	{
		global $wpdb;

        ob_start();

        $subc_front_name = $_POST['ls_vbuilder_front_template2_name_val'];
		$subc_email = $_POST['ls_vbuilder_front_template2_email_val'];
		$subc_link = $_POST['ls_vbuilder_front_template2_link_val'];
		$subc_content = stripslashes($_POST['ls_vbuilder_front_template2_content_val']);
		$subc_id = $_POST['ls_vbuilder_front_template2_id_val'];
		
		$old_words	= array("[ls_lockbuilders]", "[/ls_lockbuilders]");
		$new_words	= array("", "");

		$newphrase = str_replace($old_words, $new_words, $subc_content);
		
        $vbuilder_table = $wpdb->base_prefix . "list_builder";

        $vbuilder_count_check_result = $wpdb->get_results("SELECT * FROM ".$wpdb->base_prefix."list_builder WHERE name = '".$subc_front_name."' AND email = '".$subc_email."'");
        
        if (count($vbuilder_count_check_result) == 0)
        {
            $vbuilder_insert_data=array(
                                        'name' => $subc_front_name, 
                                        'email' => $subc_email, 
                                       );
    
            $vbuilder_insert = $wpdb->insert( $vbuilder_table, $vbuilder_insert_data); 
			if($vbuilder_insert)
			{
				?>
				<p style="color:#fff;">Content is unlocked.click here <a href="<?php echo $subc_link; ?>" style="text-decoration:none;color:#fff;"><i class="fa fa-share" aria-hidden="true"></i></a> to continue reading.</p>
				<?php				
				$cookie_name = "ls_subc_vbuilder_unlock_".$subc_id;
				$cookie_value = "ls_subc_vbuilder_unlock_value_".$subc_id;
				setcookie($cookie_name, $cookie_value, time() + (1 * 365 * 24 * 60 * 60), "/");			
			}
        }
		else
		{
			echo "11";
		}
		exit;
	}
	public function ajax_wpls_option_result()
	{
		global $wpdb;
		
		$ajax_option_template_ls = $_POST['ajax_option_template_ls'];

		$ajax_ls_button_title = $_POST['ajax_ls_button_title'];
		$ajax_ls_button_subtitle = $_POST['ajax_ls_button_subtitle'];
		$ajax_ls_button_text = $_POST['ajax_ls_button_text'];
		$ajax_ls_button_link = $_POST['ajax_ls_button_link'];
		$ajax_ls_button_image_url = $_POST['ajax_ls_button_image_url'];
		
		$ajax_ls_optin1_image_url = $_POST['ajax_ls_optin1_image_url'];
		$ajax_ls_optin1_title = $_POST['ajax_ls_optin1_title'];
		$ajax_ls_optin1_subtitle = $_POST['ajax_ls_optin1_subtitle'];
		$ajax_ls_optin1_phname = $_POST['ajax_ls_optin1_phname'];
		$ajax_ls_optin1_phemail = $_POST['ajax_ls_optin1_phemail'];
		$ajax_ls_optin1_btntext = $_POST['ajax_ls_optin1_btntext'];
		
		$ajax_ls_optin2_image_url = $_POST['ajax_ls_optin2_image_url'];
		$ajax_ls_optin2_title = $_POST['ajax_ls_optin2_title'];
		$ajax_ls_optin2_subtitle = $_POST['ajax_ls_optin2_subtitle'];
		$ajax_ls_optin2_phname = $_POST['ajax_ls_optin2_phname'];
		$ajax_ls_optin2_phemail = $_POST['ajax_ls_optin2_phemail'];
		$ajax_ls_optin2_btntext = $_POST['ajax_ls_optin2_btntext'];
		
		$ajax_ls_select_option_post_montid = $_POST['ajax_ls_select_option_post_montid'];
		$ajax_ls_option_position = $_POST['ajax_ls_option_position'];
		
		if($ajax_ls_select_option_post_montid == 'all_posts')
		{
			$posts = get_posts(array('numberposts' => -1));
			$i = 0;
			foreach($posts as $postss)
			{
				$ts_monetize_posts_id = $postss->ID;    
				$post = get_post($ts_monetize_posts_id);
				
				$post_content = $post->post_content;
				
				if($ajax_option_template_ls == 'optin1')
				{
					if($ajax_ls_option_position == 't_left')
					{						
						$string = '<div class="codeSnip my-seed-view-Form-light hj_'.$ajax_ls_option_position.'" style="display: block;z-index:1;position: fixed;text-align: center;">
							<div class="lssc_save_optin_form"></div>
							<div class="row">
								<div class="col-lg-12 text-center" id="innerValue">
									<img class="my-image-oval" id="openImage" style="width:100px;text-align:-webkit-center;" alt="Brand-image" src="'.$ajax_ls_optin1_image_url.'"><br><br>
									<h6 style="display:inline-block">'.$ajax_ls_optin1_title.'</h6>
									<p id="msg" style="text-wrap:wrap">'.$ajax_ls_optin1_subtitle.'</p>
									<p id="message"></p>
									<form id="optin_form" action="" method="post">
										<input class="Input-text" id="optin_email" type="Email" placeholder="'.$ajax_ls_optin1_phemail.'" required>
										<input class="Input-text" id="optin_name" type="text" placeholder="'.$ajax_ls_optin1_phname.'" required>
										<button class="button-text" type="Submit" >'.$ajax_ls_optin1_btntext.'</button>
									</form>
								</div>
							</div>';												
					}
					elseif($ajax_ls_option_position == 't_right')
					{
						$string = '<div class="codeSnip my-seed-view-Form-light hj_'.$ajax_ls_option_position.'" style="display: block;z-index:1;position: fixed;text-align: center;">
							<div class="lssc_save_optin_form"></div>
							<div class="row">
								<div class="col-lg-12 text-center" id="innerValue">
									<img class="my-image-oval" id="openImage" style="width:100px;text-align:-webkit-center;" alt="Brand-image" src="'.$ajax_ls_optin1_image_url.'"><br><br>
									<h6 style="display:inline-block">'.$ajax_ls_optin1_title.'</h6>
									<p id="msg" style="text-wrap:wrap">'.$ajax_ls_optin1_subtitle.'</p>
									<p id="message"></p>
									<form id="optin_form" action="" method="post">
										<input class="Input-text" id="optin_email" type="Email" placeholder="'.$ajax_ls_optin1_phemail.'" required>
										<input class="Input-text" id="optin_name" type="text" placeholder="'.$ajax_ls_optin1_phname.'" required>
										<button class="button-text" type="Submit" >'.$ajax_ls_optin1_btntext.'</button>
									</form>
								</div>
							</div>';												
					}
					elseif($ajax_ls_option_position == 't_center')
					{
						$string = '<div class="codeSnip my-seed-view-Form-light hj_'.$ajax_ls_option_position.'" style="display: block; position: fixed;z-index:1;text-align: center;">
							<div class="lssc_save_optin_form"></div>
							<div class="row">
								<div class="col-lg-12 text-center" id="innerValue">
									<img class="my-image-oval" id="openImage" style="width:100px;text-align:-webkit-center;" alt="Brand-image" src="'.$ajax_ls_optin1_image_url.'"><br><br>
									<h6 style="display:inline-block">'.$ajax_ls_optin1_title.'</h6>
									<p id="msg" style="text-wrap:wrap">'.$ajax_ls_optin1_subtitle.'</p>
									<p id="message"></p>
									<form id="optin_form" action="" method="post">
										<input class="Input-text" id="optin_email" type="Email" placeholder="'.$ajax_ls_optin1_phemail.'" required>
										<input class="Input-text" id="optin_name" type="text" placeholder="'.$ajax_ls_optin1_phname.'" required>
										<button class="button-text" type="Submit" >'.$ajax_ls_optin1_btntext.'</button>
									</form>
								</div>
							</div>';												
					}
					elseif($ajax_ls_option_position == 'b_left')
					{
						$string = '<div class="codeSnip my-seed-view-Form-light hj_'.$ajax_ls_option_position.'" style="display: block;z-index:1;position: fixed;text-align: center;">
							<div class="lssc_save_optin_form"></div>
							<div class="row">
								<div class="col-lg-12 text-center" id="innerValue">
									<img class="my-image-oval" id="openImage" style="width:100px;text-align:-webkit-center;" alt="Brand-image" src="'.$ajax_ls_optin1_image_url.'"><br><br>
									<h6 style="display:inline-block">'.$ajax_ls_optin1_title.'</h6>
									<p id="msg" style="text-wrap:wrap">'.$ajax_ls_optin1_subtitle.'</p>
									<p id="message"></p>
									<form id="optin_form" action="" method="post">
										<input class="Input-text" id="optin_email" type="Email" placeholder="'.$ajax_ls_optin1_phemail.'" required>
										<input class="Input-text" id="optin_name" type="text" placeholder="'.$ajax_ls_optin1_phname.'" required>
										<button class="button-text" type="Submit" >'.$ajax_ls_optin1_btntext.'</button>
									</form>
								</div>
							</div>';												
					}
					elseif($ajax_ls_option_position == 'b_right')
					{
						$string = '<div class="codeSnip my-seed-view-Form-light hj_'.$ajax_ls_option_position.'" style="display: block;z-index:1; position: fixed;text-align: center;">
							<div class="lssc_save_optin_form"></div>
							<div class="row">
								<div class="col-lg-12 text-center" id="innerValue">
									<img class="my-image-oval" id="openImage" style="width:100px;text-align:-webkit-center;" alt="Brand-image" src="'.$ajax_ls_optin1_image_url.'"><br><br>
									<h6 style="display:inline-block">'.$ajax_ls_optin1_title.'</h6>
									<p id="msg" style="text-wrap:wrap">'.$ajax_ls_optin1_subtitle.'</p>
									<p id="message"></p>
									<form id="optin_form" action="" method="post">
										<input class="Input-text" id="optin_email" type="Email" placeholder="'.$ajax_ls_optin1_phemail.'" required>
										<input class="Input-text" id="optin_name" type="text" placeholder="'.$ajax_ls_optin1_phname.'" required>
										<button class="button-text" type="Submit" >'.$ajax_ls_optin1_btntext.'</button>
									</form>
								</div>
							</div>';												
					}
					elseif($ajax_ls_option_position == 'b_center')
					{
						$string = '<div class="codeSnip my-seed-view-Form-light hj_'.$ajax_ls_option_position.'" style="display: block;z-index:1; position: fixed;text-align: center;">
							<div class="lssc_save_optin_form"></div>
							<div class="row">
								<div class="col-lg-12 text-center" id="innerValue">
									<img class="my-image-oval" id="openImage" style="width:100px;text-align:-webkit-center;" alt="Brand-image" src="'.$ajax_ls_optin1_image_url.'"><br><br>
									<h6 style="display:inline-block">'.$ajax_ls_optin1_title.'</h6>
									<p id="msg" style="text-wrap:wrap">'.$ajax_ls_optin1_subtitle.'</p>
									<p id="message"></p>
									<form id="optin_form" action="" method="post">
										<input class="Input-text" id="optin_email" type="Email" placeholder="'.$ajax_ls_optin1_phemail.'" required>
										<input class="Input-text" id="optin_name" type="text" placeholder="'.$ajax_ls_optin1_phname.'" required>
										<button class="button-text" type="Submit" >'.$ajax_ls_optin1_btntext.'</button>
									</form>
								</div>
							</div>';												
					}
				}
				elseif($ajax_option_template_ls == 'optin2')
				{
					if($ajax_ls_option_position == 't_left')
					{						
						$string = '<div class="codeSnip my-seed-view-Form-dark hj_'.$ajax_ls_option_position.'" style="display: block;z-index:1; position: fixed;text-align: center;">
								<div class="lssc_save_optin_form"></div>
								<div class="row">
									<div class="col-lg-12 text-center" id="innerValue">
										<img class="my-image-oval" id="openImage" style="width:100px;text-align:-webkit-center;" alt="Brand-image" src="'.$ajax_ls_optin2_image_url.'"><br><br>
										<h6 style="display:inline-block">'.$ajax_ls_optin2_title.'</h6>
										<p id="msg" style="text-wrap:wrap">'.$ajax_ls_optin2_subtitle.'</p>
										<p id="message"></p>
										<form id="optin_form" action="" method="post">
											<input class="Input-text" id="optin_email" type="Email" placeholder="'.$ajax_ls_optin2_phemail.'" required>
											<input class="Input-text" id="optin_name" type="text" placeholder="'.$ajax_ls_optin2_phname.'" required>
											<button class="button-text" type="Submit" >'.$ajax_ls_optin2_btntext.'</button>
										</form>
									</div>
								</div>
							</div>';	
					}
					elseif($ajax_ls_option_position == 't_right')
					{
						$string = '<div class="codeSnip my-seed-view-Form-dark hj_'.$ajax_ls_option_position.'" style="display: block;z-index:1; position: fixed;text-align: center;">
								<div class="lssc_save_optin_form"></div>
								<div class="row">
									<div class="col-lg-12 text-center" id="innerValue">
										<img class="my-image-oval" id="openImage" style="width:100px;text-align:-webkit-center;" alt="Brand-image" src="'.$ajax_ls_optin2_image_url.'"><br><br>
										<h6 style="display:inline-block">'.$ajax_ls_optin2_title.'</h6>
										<p id="msg" style="text-wrap:wrap">'.$ajax_ls_optin2_subtitle.'</p>
										<p id="message"></p>
										<form id="optin_form" action="" method="post">
											<input class="Input-text" id="optin_email" type="Email" placeholder="'.$ajax_ls_optin2_phemail.'" required>
											<input class="Input-text" id="optin_name" type="text" placeholder="'.$ajax_ls_optin2_phname.'" required>
											<button class="button-text" type="Submit" >'.$ajax_ls_optin2_btntext.'</button>
										</form>
									</div>
								</div>
							</div>';	
					}
					elseif($ajax_ls_option_position == 't_center')
					{
						$string = '<div class="codeSnip my-seed-view-Form-dark hj_'.$ajax_ls_option_position.'" style="display: block;z-index:1; position: fixed;text-align: center;">
								<div class="lssc_save_optin_form"></div>
								<div class="row">
									<div class="col-lg-12 text-center" id="innerValue">
										<img class="my-image-oval" id="openImage" style="width:100px;text-align:-webkit-center;" alt="Brand-image" src="'.$ajax_ls_optin2_image_url.'"><br><br>
										<h6 style="display:inline-block">'.$ajax_ls_optin2_title.'</h6>
										<p id="msg" style="text-wrap:wrap">'.$ajax_ls_optin2_subtitle.'</p>
										<p id="message"></p>
										<form id="optin_form" action="" method="post">
											<input class="Input-text" id="optin_email" type="Email" placeholder="'.$ajax_ls_optin2_phemail.'" required>
											<input class="Input-text" id="optin_name" type="text" placeholder="'.$ajax_ls_optin2_phname.'" required>
											<button class="button-text" type="Submit" >'.$ajax_ls_optin2_btntext.'</button>
										</form>
									</div>
								</div>
							</div>';	
					}
					elseif($ajax_ls_option_position == 'b_left')
					{
						$string = '<div class="codeSnip my-seed-view-Form-dark hj_'.$ajax_ls_option_position.'" style="display: block;z-index:1; position: fixed;text-align: center;">
								<div class="lssc_save_optin_form"></div>
								<div class="row">
									<div class="col-lg-12 text-center" id="innerValue">
										<img class="my-image-oval" id="openImage" style="width:100px;text-align:-webkit-center;" alt="Brand-image" src="'.$ajax_ls_optin2_image_url.'"><br><br>
										<h6 style="display:inline-block">'.$ajax_ls_optin2_title.'</h6>
										<p id="msg" style="text-wrap:wrap">'.$ajax_ls_optin2_subtitle.'</p>
										<p id="message"></p>
										<form id="optin_form" action="" method="post">
											<input class="Input-text" id="optin_email" type="Email" placeholder="'.$ajax_ls_optin2_phemail.'" required>
											<input class="Input-text" id="optin_name" type="text" placeholder="'.$ajax_ls_optin2_phname.'" required>
											<button class="button-text" type="Submit" >'.$ajax_ls_optin2_btntext.'</button>
										</form>
									</div>
								</div>
							</div>';	
					}
					elseif($ajax_ls_option_position == 'b_right')
					{
						$string = '<div class="codeSnip my-seed-view-Form-dark hj_'.$ajax_ls_option_position.'" style="display: block;z-index:1; position: fixed;text-align: center;">
								<div class="lssc_save_optin_form"></div>
								<div class="row">
									<div class="col-lg-12 text-center" id="innerValue">
										<img class="my-image-oval" id="openImage" style="width:100px;text-align:-webkit-center;" alt="Brand-image" src="'.$ajax_ls_optin2_image_url.'"><br><br>
										<h6 style="display:inline-block">'.$ajax_ls_optin2_title.'</h6>
										<p id="msg" style="text-wrap:wrap">'.$ajax_ls_optin2_subtitle.'</p>
										<p id="message"></p>
										<form id="optin_form" action="" method="post">
											<input class="Input-text" id="optin_email" type="Email" placeholder="'.$ajax_ls_optin2_phemail.'" required>
											<input class="Input-text" id="optin_name" type="text" placeholder="'.$ajax_ls_optin2_phname.'" required>
											<button class="button-text" type="Submit" >'.$ajax_ls_optin2_btntext.'</button>
										</form>
									</div>
								</div>
							</div>';	
					}
					elseif($ajax_ls_option_position == 'b_center')
					{
						$string = '<div class="codeSnip my-seed-view-Form-dark hj_'.$ajax_ls_option_position.'" style="display: block;z-index:1; position: fixed;text-align: center;">
								<div class="lssc_save_optin_form"></div>
								<div class="row">
									<div class="col-lg-12 text-center" id="innerValue">
										<img class="my-image-oval" id="openImage" style="width:100px;text-align:-webkit-center;" alt="Brand-image" src="'.$ajax_ls_optin2_image_url.'"><br><br>
										<h6 style="display:inline-block">'.$ajax_ls_optin2_title.'</h6>
										<p id="msg" style="text-wrap:wrap">'.$ajax_ls_optin2_subtitle.'</p>
										<p id="message"></p>
										<form id="optin_form" action="" method="post">
											<input class="Input-text" id="optin_email" type="Email" placeholder="'.$ajax_ls_optin2_phemail.'" required>
											<input class="Input-text" id="optin_name" type="text" placeholder="'.$ajax_ls_optin2_phname.'" required>
											<button class="button-text" type="Submit" >'.$ajax_ls_optin2_btntext.'</button>
										</form>
									</div>
								</div>
							</div>';	
					}
				}

				
				$option_name = 'option_form_ls_post_'.$ts_monetize_posts_id;
				$s = array();
				$s['option_form_ls'] = $string;
				$s['post_id'] = $ts_monetize_posts_id;
				$s['option_templ_name'] = $ajax_option_template_ls;
				$new_value = $s;
				 
				if ( get_option( $option_name ) !== false ) {
				 
					// The option already exists, so update it.
					if(update_option( $option_name, $new_value ))
					{ if($i == 0) {					
					?>
					<div class="wrap">
						<div class="updated"><p style="margin:5px;">Optin form is updated</p></div>
					</div>
					<?php
					} }				 
				} else {				 
					// The option hasn't been created yet, so add it with $autoload set to 'no'.
					$deprecated = null;
					$autoload = 'no';
					if(add_option( $option_name, $new_value, $deprecated, $autoload ))
					{ if($i == 0) {	 				
					?>
					<div class="wrap">
						<div class="updated"><p style="margin:5px;">Optin form is saved</p></div>
					</div>
					<?php
					} }
				}
				$i++;
			}		
		}
		elseif($ajax_ls_select_option_post_montid != 'all_posts')
		{
			if($ajax_option_template_ls == 'optin1')
			{
				if($ajax_ls_option_position == 't_left')
				{
					$string = '<div class="codeSnip my-seed-view-Form-light hj_'.$ajax_ls_option_position.'" style="display: block;z-index:1; position: fixed;text-align: center;">
						<div class="lssc_save_optin_form"></div>
						<div class="row">
							<div class="col-lg-12 text-center" id="innerValue">
								<img class="my-image-oval" id="openImage" style="width:100px;text-align:-webkit-center;" alt="Brand-image" src="'.$ajax_ls_optin1_image_url.'"><br><br>
								<h6 style="display:inline-block">'.$ajax_ls_optin1_title.'</h6>
								<p id="msg" style="text-wrap:wrap">'.$ajax_ls_optin1_subtitle.'</p>
								<p id="message"></p>
								<form id="optin_form" action="" method="post">
									<input class="Input-text" id="optin_email" type="Email" placeholder="'.$ajax_ls_optin1_phemail.'" required>
									<input class="Input-text" id="optin_name" type="text" placeholder="'.$ajax_ls_optin1_phname.'" required>
									<button class="button-text" type="Submit" >'.$ajax_ls_optin1_btntext.'</button>
								</form>
							</div>
						</div>';												
				}
				elseif($ajax_ls_option_position == 't_right')
				{
					$string = '<div class="codeSnip my-seed-view-Form-light hj_'.$ajax_ls_option_position.'" style="display: block;z-index:1; position: fixed;text-align: center;">
						<div class="lssc_save_optin_form"></div>
						<div class="row">
							<div class="col-lg-12 text-center" id="innerValue">
								<img class="my-image-oval" id="openImage" style="width:100px;text-align:-webkit-center;" alt="Brand-image" src="'.$ajax_ls_optin1_image_url.'"><br><br>
								<h6 style="display:inline-block">'.$ajax_ls_optin1_title.'</h6>
								<p id="msg" style="text-wrap:wrap">'.$ajax_ls_optin1_subtitle.'</p>
								<p id="message"></p>
								<form id="optin_form" action="" method="post">
									<input class="Input-text" id="optin_email" type="Email" placeholder="'.$ajax_ls_optin1_phemail.'" required>
									<input class="Input-text" id="optin_name" type="text" placeholder="'.$ajax_ls_optin1_phname.'" required>
									<button class="button-text" type="Submit" >'.$ajax_ls_optin1_btntext.'</button>
								</form>
							</div>
						</div>';												
				}
				elseif($ajax_ls_option_position == 't_center')
				{
					$string = '<div class="codeSnip my-seed-view-Form-light hj_'.$ajax_ls_option_position.'" style="display: block;z-index:1; position: fixed;text-align: center;">
						<div class="lssc_save_optin_form"></div>
						<div class="row">
							<div class="col-lg-12 text-center" id="innerValue">
								<img class="my-image-oval" id="openImage" style="width:100px;text-align:-webkit-center;" alt="Brand-image" src="'.$ajax_ls_optin1_image_url.'"><br><br>
								<h6 style="display:inline-block">'.$ajax_ls_optin1_title.'</h6>
								<p id="msg" style="text-wrap:wrap">'.$ajax_ls_optin1_subtitle.'</p>
								<p id="message"></p>
								<form id="optin_form" action="" method="post">
									<input class="Input-text" id="optin_email" type="Email" placeholder="'.$ajax_ls_optin1_phemail.'" required>
									<input class="Input-text" id="optin_name" type="text" placeholder="'.$ajax_ls_optin1_phname.'" required>
									<button class="button-text" type="Submit" >'.$ajax_ls_optin1_btntext.'</button>
								</form>
							</div>
						</div>';												
				}
				elseif($ajax_ls_option_position == 'b_left')
				{
					$string = '<div class="codeSnip my-seed-view-Form-light hj_'.$ajax_ls_option_position.'" style="display: block;z-index:1; position: fixed;text-align: center;">
						<div class="lssc_save_optin_form"></div>
						<div class="row">
							<div class="col-lg-12 text-center" id="innerValue">
								<img class="my-image-oval" id="openImage" style="width:100px;text-align:-webkit-center;" alt="Brand-image" src="'.$ajax_ls_optin1_image_url.'"><br><br>
								<h6 style="display:inline-block">'.$ajax_ls_optin1_title.'</h6>
								<p id="msg" style="text-wrap:wrap">'.$ajax_ls_optin1_subtitle.'</p>
								<p id="message"></p>
								<form id="optin_form" action="" method="post">
									<input class="Input-text" id="optin_email" type="Email" placeholder="'.$ajax_ls_optin1_phemail.'" required>
									<input class="Input-text" id="optin_name" type="text" placeholder="'.$ajax_ls_optin1_phname.'" required>
									<button class="button-text" type="Submit" >'.$ajax_ls_optin1_btntext.'</button>
								</form>
							</div>
						</div>';												
				}
				elseif($ajax_ls_option_position == 'b_right')
				{
					$string = '<div class="codeSnip my-seed-view-Form-light hj_'.$ajax_ls_option_position.'" style="display: block;z-index:1; position: fixed;text-align: center;">
						<div class="lssc_save_optin_form"></div>
						<div class="row">
							<div class="col-lg-12 text-center" id="innerValue">
								<img class="my-image-oval" id="openImage" style="width:100px;text-align:-webkit-center;" alt="Brand-image" src="'.$ajax_ls_optin1_image_url.'"><br><br>
								<h6 style="display:inline-block">'.$ajax_ls_optin1_title.'</h6>
								<p id="msg" style="text-wrap:wrap">'.$ajax_ls_optin1_subtitle.'</p>
								<p id="message"></p>
								<form id="optin_form" action="" method="post">
									<input class="Input-text" id="optin_email" type="Email" placeholder="'.$ajax_ls_optin1_phemail.'" required>
									<input class="Input-text" id="optin_name" type="text" placeholder="'.$ajax_ls_optin1_phname.'" required>
									<button class="button-text" type="Submit" >'.$ajax_ls_optin1_btntext.'</button>
								</form>
							</div>
						</div>';												
				}
				elseif($ajax_ls_option_position == 'b_center')
				{
					$string = '<div class="codeSnip my-seed-view-Form-light hj_'.$ajax_ls_option_position.'" style="display: block;z-index:1; position: fixed;text-align: center;">
						<div class="lssc_save_optin_form"></div>
						<div class="row">
							<div class="col-lg-12 text-center" id="innerValue">
								<img class="my-image-oval" id="openImage" style="width:100px;text-align:-webkit-center;" alt="Brand-image" src="'.$ajax_ls_optin1_image_url.'"><br><br>
								<h6 style="display:inline-block">'.$ajax_ls_optin1_title.'</h6>
								<p id="msg" style="text-wrap:wrap">'.$ajax_ls_optin1_subtitle.'</p>
								<p id="message"></p>
								<form id="optin_form" action="" method="post">
									<input class="Input-text" id="optin_email" type="Email" placeholder="'.$ajax_ls_optin1_phemail.'" required>
									<input class="Input-text" id="optin_name" type="text" placeholder="'.$ajax_ls_optin1_phname.'" required>
									<button class="button-text" type="Submit" >'.$ajax_ls_optin1_btntext.'</button>
								</form>
							</div>
						</div>';												
				}
			}
			elseif($ajax_option_template_ls == 'optin2')
			{
				if($ajax_ls_option_position == 't_left')
				{						
					$string = '<div class="codeSnip my-seed-view-Form-dark hj_'.$ajax_ls_option_position.'" style="display: block;z-index:1; position: fixed;text-align: center;">
							<div class="lssc_save_optin_form"></div>
							<div class="row">
								<div class="col-lg-12 text-center" id="innerValue">
									<img class="my-image-oval" id="openImage" style="width:100px;text-align:-webkit-center;" alt="Brand-image" src="'.$ajax_ls_optin2_image_url.'"><br><br>
									<h6 style="display:inline-block">'.$ajax_ls_optin2_title.'</h6>
									<p id="msg" style="text-wrap:wrap">'.$ajax_ls_optin2_subtitle.'</p>
									<p id="message"></p>
									<form id="optin_form" action="" method="post">
										<input class="Input-text" id="optin_email" type="Email" placeholder="'.$ajax_ls_optin2_phemail.'" required>
										<input class="Input-text" id="optin_name" type="text" placeholder="'.$ajax_ls_optin2_phname.'" required>
										<button class="button-text" type="Submit" >'.$ajax_ls_optin2_btntext.'</button>
									</form>
								</div>
							</div>
						</div>';	
				}
				elseif($ajax_ls_option_position == 't_right')
				{
					$string = '<div class="codeSnip my-seed-view-Form-dark hj_'.$ajax_ls_option_position.'" style="display: block;z-index:1; position: fixed;text-align: center;">
							<div class="lssc_save_optin_form"></div>
							<div class="row">
								<div class="col-lg-12 text-center" id="innerValue">
									<img class="my-image-oval" id="openImage" style="width:100px;text-align:-webkit-center;" alt="Brand-image" src="'.$ajax_ls_optin2_image_url.'"><br><br>
									<h6 style="display:inline-block">'.$ajax_ls_optin2_title.'</h6>
									<p id="msg" style="text-wrap:wrap">'.$ajax_ls_optin2_subtitle.'</p>
									<p id="message"></p>
									<form id="optin_form" action="" method="post">
										<input class="Input-text" id="optin_email" type="Email" placeholder="'.$ajax_ls_optin2_phemail.'" required>
										<input class="Input-text" id="optin_name" type="text" placeholder="'.$ajax_ls_optin2_phname.'" required>
										<button class="button-text" type="Submit" >'.$ajax_ls_optin2_btntext.'</button>
									</form>
								</div>
							</div>
						</div>';	
				}
				elseif($ajax_ls_option_position == 't_center')
				{
					$string = '<div class="codeSnip my-seed-view-Form-dark hj_'.$ajax_ls_option_position.'" style="display: block;z-index:1; position: fixed;text-align: center;">
							<div class="lssc_save_optin_form"></div>
							<div class="row">
								<div class="col-lg-12 text-center" id="innerValue">
									<img class="my-image-oval" id="openImage" style="width:100px;text-align:-webkit-center;" alt="Brand-image" src="'.$ajax_ls_optin2_image_url.'"><br><br>
									<h6 style="display:inline-block">'.$ajax_ls_optin2_title.'</h6>
									<p id="msg" style="text-wrap:wrap">'.$ajax_ls_optin2_subtitle.'</p>
									<p id="message"></p>
									<form id="optin_form" action="" method="post">
										<input class="Input-text" id="optin_email" type="Email" placeholder="'.$ajax_ls_optin2_phemail.'" required>
										<input class="Input-text" id="optin_name" type="text" placeholder="'.$ajax_ls_optin2_phname.'" required>
										<button class="button-text" type="Submit" >'.$ajax_ls_optin2_btntext.'</button>
									</form>
								</div>
							</div>
						</div>';	
				}
				elseif($ajax_ls_option_position == 'b_left')
				{
					$string = '<div class="codeSnip my-seed-view-Form-dark hj_'.$ajax_ls_option_position.'" style="display: block;z-index:1; position: fixed;text-align: center;">
							<div class="lssc_save_optin_form"></div>
							<div class="row">
								<div class="col-lg-12 text-center" id="innerValue">
									<img class="my-image-oval" id="openImage" style="width:100px;text-align:-webkit-center;" alt="Brand-image" src="'.$ajax_ls_optin2_image_url.'"><br><br>
									<h6 style="display:inline-block">'.$ajax_ls_optin2_title.'</h6>
									<p id="msg" style="text-wrap:wrap">'.$ajax_ls_optin2_subtitle.'</p>
									<p id="message"></p>
									<form id="optin_form" action="" method="post">
										<input class="Input-text" id="optin_email" type="Email" placeholder="'.$ajax_ls_optin2_phemail.'" required>
										<input class="Input-text" id="optin_name" type="text" placeholder="'.$ajax_ls_optin2_phname.'" required>
										<button class="button-text" type="Submit" >'.$ajax_ls_optin2_btntext.'</button>
									</form>
								</div>
							</div>
						</div>';	
				}
				elseif($ajax_ls_option_position == 'b_right')
				{
					$string = '<div class="codeSnip my-seed-view-Form-dark hj_'.$ajax_ls_option_position.'" style="display: block;z-index:1; position: fixed;text-align: center;">
							<div class="lssc_save_optin_form"></div>
							<div class="row">
								<div class="col-lg-12 text-center" id="innerValue">
									<img class="my-image-oval" id="openImage" style="width:100px;text-align:-webkit-center;" alt="Brand-image" src="'.$ajax_ls_optin2_image_url.'"><br><br>
									<h6 style="display:inline-block">'.$ajax_ls_optin2_title.'</h6>
									<p id="msg" style="text-wrap:wrap">'.$ajax_ls_optin2_subtitle.'</p>
									<p id="message"></p>
									<form id="optin_form" action="" method="post">
										<input class="Input-text" id="optin_email" type="Email" placeholder="'.$ajax_ls_optin2_phemail.'" required>
										<input class="Input-text" id="optin_name" type="text" placeholder="'.$ajax_ls_optin2_phname.'" required>
										<button class="button-text" type="Submit" >'.$ajax_ls_optin2_btntext.'</button>
									</form>
								</div>
							</div>
						</div>';	
				}
				elseif($ajax_ls_option_position == 'b_center')
				{
					$string = '<div class="codeSnip my-seed-view-Form-dark hj_'.$ajax_ls_option_position.'" style="display: block;z-index:1; position: fixed;text-align: center;">
							<div class="lssc_save_optin_form"></div>
							<div class="row">
								<div class="col-lg-12 text-center" id="innerValue">
									<img class="my-image-oval" id="openImage" style="width:100px;text-align:-webkit-center;" alt="Brand-image" src="'.$ajax_ls_optin2_image_url.'"><br><br>
									<h6 style="display:inline-block">'.$ajax_ls_optin2_title.'</h6>
									<p id="msg" style="text-wrap:wrap">'.$ajax_ls_optin2_subtitle.'</p>
									<p id="message"></p>
									<form id="optin_form" action="" method="post">
										<input class="Input-text" id="optin_email" type="Email" placeholder="'.$ajax_ls_optin2_phemail.'" required>
										<input class="Input-text" id="optin_name" type="text" placeholder="'.$ajax_ls_optin2_phname.'" required>
										<button class="button-text" type="Submit" >'.$ajax_ls_optin2_btntext.'</button>
									</form>
								</div>
							</div>
						</div>';	
				}
			}

			$option_name = 'option_form_ls_post_'.$ajax_ls_select_option_post_montid;
			$s = array();
			$s['option_form_ls'] = $string;
			$s['post_id'] = $ajax_ls_select_option_post_montid;
			$s['option_templ_name'] = $ajax_option_template_ls;
			$new_value = $s;
			 
			if ( get_option( $option_name ) !== false ) {
			 
				// The option already exists, so update it.
				if(update_option( $option_name, $new_value ))
				{					
				?>
				<div class="wrap">
					<div class="updated"><p style="margin:5px;">Optin form is updated</p></div>
				</div>
				<?php
				}				 
			} else {				 
				// The option hasn't been created yet, so add it with $autoload set to 'no'.
				$deprecated = null;
				$autoload = 'no';
				if(add_option( $option_name, $new_value, $deprecated, $autoload ))
				{
				?>
				<div class="wrap">
					<div class="updated"><p style="margin:5px;">Optin form is saved</p></div>
				</div>
				<?php
				} 
			}			
		}
		?>
		<script>
		jQuery(function() {
			setTimeout(function() {
				  jQuery('.updated').fadeOut('slow');
				}, 6000); // <-- time in milliseconds
			setTimeout(function() {
				  jQuery('.error').fadeOut('slow');
				}, 6000); // <-- time in milliseconds
		});
		</script>
		<?php
		exit;
	}
	
	public function wpls_show_optin_form_boxx()
	{
		global $wpdb,$post,$pagenow;
		
		ini_set('display_errors','Off');
		error_reporting(0);
		
		ob_start();		

		$s_return = '';
		$id = get_the_ID();
		$content = wpautop(get_the_content());
		
		$option_name = 'option_form_ls_post_'.$id;
		$opt_name = get_option( $option_name );
		?>
		<link href="<?php echo LS_PLUGIN_URL; ?>ls-viral-campaign/css/wpls-viral-builder-traffic.css" rel="stylesheet">
		<script src="<?php echo LS_PLUGIN_URL; ?>ls-viral-campaign/js/jquery.min.js"></script>
		<?php
		$s_return .= '<style>
			.entry-content > *
			{
				margin-top: 0;
			}
			.entry-content
			{
				margin-bottom:-28px;
			}
		  .dsclmr_box{font-size: 10px;font-style: italic;padding: 5px 5px 0;word-break: break-word;}
		  .dsclmr_btn,.dsclmr_ptn1{width: 100%;}
		  .dsclmr_video{width: 560px;}
		  .dsclmr_img{width: 100%;color:#000;}
		  .alert{width:96%;}
		  p {
				word-break: normal !important;
			}
		  </style>';
		$s_return .='<input type="hidden" id="op_id" value="'.$id.'">';  
		$cookie_name_opt = 'option_form_ls_post_'.$id;
		if(!isset($_COOKIE[$cookie_name_opt]))
		{			
			$s_return .= $content;
			$s_return .= $opt_name['option_form_ls'];	
			$s_return .= '<script>
			jQuery(document).ready(function($){
				$(document).on("click", ".button-text", function() {
				var name = $("#optin_name").val();				
				var email = $("#optin_email").val();				
				var opt_id = $("#op_id").val();				
				var url = wpls_ajax.ajax_url;
				
				var d = new Date();
				var cname = "option_form_ls_post_"+opt_id;
				var cvalue = "option_form_ls_value_"+opt_id;
				d.setTime(d.getTime() + (3650 * 24 * 60 * 60 * 1000));
				var expires = "expires="+d.toUTCString();
				document.cookie = cname + "=" + cvalue + ";" + expires + ";path=/";	

			  jQuery.ajax({
					url:  url,
					type: "POST",
					data: {
						action:"wpls_save_optin_form",
						name:name,
						email:email,
						opt_id:opt_id,
					},
					beforeSend: function(){
						$(".button-text").html("Saving...");
					},
					success: function (response) {
						$(".button-text").html("Done!");
						return false;
					}
				});	
			});
			});
			</script>';			  
		}
		else
		{
			$s_return .='<script>
			jQuery(document).ready(function($){
				$(".codeSnip").css("display","none");					
			});
			</script>';			  			
			$s_return .= $content;
		}
			$s_return .='<script>
			jQuery(document).ready(function($){
				$("p:empty").remove();
			});
			</script>';			  			
		$s_return .= ob_get_clean();
		
		return $s_return;
	}
	
	public function ajax_wpls_save_optin_form()
	{
		global $wpdb; 
		
		$op_form_name = $_POST['name'];
		$op_form_email = $_POST['email'];	
		$op_form_id = $_POST['opt_id'];	
		
		$ls_opt_form_tmp_table = $wpdb->base_prefix . "list_builder";

		$ls_count_check_result = $wpdb->get_results("SELECT * FROM ".$wpdb->base_prefix."list_builder WHERE email = '".$op_form_email."'");
		
		if (count($ls_count_check_result) == 0)
		{
			$ls_opt_form_datas=array(
										'name' => $op_form_name, 
										'email' => $op_form_email, 
										'updated_at' => date('Y-m-d-H:i:s'),
										'created_at' => date('Y-m-d-H:i:s'), 	
									   );
	
			$wpdb->insert( $ls_opt_form_tmp_table, $ls_opt_form_datas); 
		}		
	}
	
	
	public function wpls_email_export_csv_process(){
		
		global $wpdb;
    	//$ts_campaign_leads = $wpdb->prefix."ts_campaign_leads";
	
		$list_builder = $wpdb->prefix . 'list_builder';
		$leads = $wpdb->get_results("SELECT * FROM ".$list_builder." ORDER BY id DESC");

		//$campaigns = $wpdb->get_results ("SELECT * from  " . $ts_campaign_leads." WHERE campaign_id =$campid");
		$list=array();
		
		if (!empty($leads)){
			$list[] =array('Email');	
			foreach($leads as $k=>$row){
				$list[] =array($row->email);
			}
		}
		$file = fopen(LS_PLUGIN_PATH."traffic/list.csv","w");
		foreach ($list as $line) {
		    fputcsv($file, $line);
		}
		fclose($file);		
		die();		
		
	}
}